@@ -41,9 +41,10 @@ for xml_context_bytes in 0 1024; do
             --error-exitcode=1
             --force
             --check-level=exhaustive
-            --suppress=objectIndex
-            --suppress=unknownMacro
+            --inline-suppr
             '-D__has_attribute(x)=1'
+            '-DEXPAT_FMT_SIZE_T(x)=%llu'
+            '-DEXPAT_FMT_ULL(x)=%llu'
             -DXML_CONTEXT_BYTES=${xml_context_bytes}
             -DXML_GE=${xml_ge}
         )
